@@ -73,10 +73,12 @@ class CRMLeadFromContractForm:
     def __init__(
         self,
         contract_data,
+        partner_data,
         subscription_request_id=None,
         partner_id=None,
     ):
         self.contract_data = contract_data
+        self.partner_data = partner_data
         self.partner_id = partner_id
         self.subscription_request_id = subscription_request_id
 
@@ -121,13 +123,19 @@ class CRMLeadFromContractForm:
             mobile_isp_info_data.update(
                 {
                     "phone_number": self.contract_data.get("mobile_phone_number"),
-                    "previous_provider": int(self.contract_data.get(
-                        "mobile_telecom_company",
-                    )),
+                    "previous_provider": int(
+                        self.contract_data.get(
+                            "mobile_telecom_company",
+                        )
+                    ),
                     "previous_owner_vat_number": self.contract_data.get(
                         "mobile_vat_number"
                     ),
-                    "previous_owner_name": self.contract_data.get("mobile_surname"),
+                    "previous_owner_name": (
+                        self.contract_data.get("mobile_surname")
+                        or self.contract_data.get("tradename")
+                        or ""
+                    ),
                     "previous_owner_first_name": self.contract_data.get("mobile_name"),
                     "icc_donor": self.contract_data.get("mobile_icc_number"),
                     "previous_contract_type": self.contract_data.get(
@@ -153,6 +161,18 @@ class CRMLeadFromContractForm:
                     }
                 }
             )
+        if self.partner_data.get("invoice_street"):
+            mobile_isp_info_data.update(
+                {
+                    "invoice_address": {
+                        "street": self.partner_data.get("invoice_street"),
+                        "zip_code": self.partner_data.get("invoice_zip"),
+                        "city": self.partner_data.get("invoice_city"),
+                        "state": self.partner_data.get("invoice_subdivision"),
+                        "country": self.partner_data.get("invoice_country"),
+                    }
+                }
+            )
         return mobile_isp_info_data
 
     def _keep_phone_number(self):
@@ -177,18 +197,22 @@ class CRMLeadFromContractForm:
             broadband_isp_info_data.update(
                 {
                     "phone_number": self.contract_data.get("internet_phone_now"),
-                    "previous_provider": int(self.contract_data.get(
-                        "internet_telecom_company"
-                    )),
+                    "previous_provider": int(
+                        self.contract_data.get("internet_telecom_company")
+                    ),
                     "previous_owner_vat_number": self.contract_data.get(
                         "internet_vat_number"
                     ),
-                    "previous_owner_name": self.contract_data.get("internet_surname"),
+                    "previous_owner_name": (
+                        self.contract_data.get("internet_surname")
+                        or self.contract_data.get("tradename")
+                        or ""
+                    ),
                     "previous_owner_first_name": self.contract_data.get(
                         "internet_name"
                     ),
                     "previous_service": self._previous_broadband_service(),
-                    "keep_phone_number": self._keep_phone_number()
+                    "keep_phone_number": self._keep_phone_number(),
                 }
             )
         if self.contract_data.get("internet_delivery_street"):
@@ -205,10 +229,22 @@ class CRMLeadFromContractForm:
                     }
                 }
             )
+        if self.partner_data.get("invoice_street"):
+            broadband_isp_info_data.update(
+                {
+                    "invoice_address": {
+                        "street": self.partner_data.get("invoice_street"),
+                        "zip_code": self.partner_data.get("invoice_zip"),
+                        "city": self.partner_data.get("invoice_city"),
+                        "state": self.partner_data.get("invoice_subdivision"),
+                        "country": self.partner_data.get("invoice_country"),
+                    }
+                }
+            )
         return broadband_isp_info_data
 
     def _previous_broadband_service(self):
         previous_service = self.contract_data.get("internet_now")
-        if previous_service == 'fibre':
-            previous_service = 'fiber'
+        if previous_service == "fibre":
+            previous_service = "fiber"
         return previous_service
