@@ -65,7 +65,8 @@ class SubscriptionRequestFromPartnerForm:
             "name": name,
             "firstname": self.partner_data.get("name"),
             "lastname": " ".join(
-                [self.partner_data.get("surname"), self.partner_data.get("lastname")]),
+                [self.partner_data.get("surname"), self.partner_data.get("lastname")]
+            ),
             "email": self.partner_data.get("email"),
             "phone": self.partner_data.get("phone"),
             "address": {
@@ -81,17 +82,15 @@ class SubscriptionRequestFromPartnerForm:
             "payment_type": self._payment_type(),
             "nationality": self.partner_data.get("nationality"),
             "discovery_channel_id": int(self.partner_data.get("discovery_channel")),
-
             "sponsor_vat": self.partner_data.get("partner_number"),
             "birthdate": self.partner_data.get("birth_date").strftime("%Y-%m-%d"),
             "gender": self.partner_data.get("sex"),
             "is_company": self._is_company(),
             "company_name": self.partner_data.get("tradename"),
-
             # TODO: Lastname, Tradename, Phone???
-            "voluntary_contribution": int(self.partner_data.get(
-                "contribute_somconnexio_option"
-            )),
+            "voluntary_contribution": int(
+                self.partner_data.get("contribute_somconnexio_option")
+            ),
         }
 
     def _get_name(self):
@@ -102,8 +101,9 @@ class SubscriptionRequestFromPartnerForm:
                 [
                     self.partner_data.get("name"),
                     self.partner_data.get("surname"),
-                    self.partner_data.get("lastname")
-                ])
+                    self.partner_data.get("lastname"),
+                ]
+            )
 
     def _is_company(self):
         if self.partner_data.get("party_type") == "organization":
