@@ -18,11 +18,7 @@ def vcr_config():
 class PartnerTests(unittest.TestCase):
     @pytest.mark.vcr()
     def test_search_resource_not_found(self):
-        self.assertRaises(
-            ResourceNotFound,
-            Partner.search_by_vat,
-            vat=''
-        )
+        self.assertRaises(ResourceNotFound, Partner.search_by_vat, vat="")
 
     @pytest.mark.vcr()
     def test_search_by_vat(self):
